## Try SmooSense with these demo files:

### images-emb-2d.parquet

Explore COCO dataset images using embedding. Check balance between training/testing/validation.

### bbox.parquet

Slice-n-dice dataset for COCO object detection. Visualize bounding box in place.

### compare-video-generation.parquet

Compare two video generation models, side by side

## Examples of multimodal visualization

### Text-to-Image Alignment

imageimage_maskword_scores

### Text-to-Video Compare

videoimage

### Object Detection with bounding box

bboximage

### 3D Objects(coming soon)

3d

### Pose Skeleton(coming soon)

skeleton